@@ -8,9 +8,9 @@
     }
     cat("\nCall:\n")
     cat(deparse(x$call), "\n")
-    statnam <- if (x$method == "rda") 
-        "sums"
-    else "averages"
+    statnam <- if (x$method == "cca") 
+        "averages"
+    else "sums"
     cat("\nPartitioning of ", x$inertia, ":\n", sep = "")
     out <- c(Total = x$tot.chi, Conditioned = x$partial.chi, 
              Constrained = x$constr.chi, Unconstrained = x$unconst.chi)
@@ -52,10 +52,14 @@
     if (x$scaling < 0) {
         if (x$method == "cca") 
             cat("* Hill scaling performed on both scores\n")
-        if (x$method == "rda") 
+        else 
             cat("* Species scores divided by species standard deviations\n")
         cat("  so that they no longer are biplot scores\n")
     }
+    if (x$method != "cca") {
+        cat("* General scaling constant of scores: ",
+            attr(x, "const"), "\n")
+    }
     if (!is.null(x$species)) {
         cat("\n\nSpecies scores\n\n")
         hcat(x$species, head=head, tail=tail, digits = digits, ...)
@@ -79,4 +83,3 @@
     cat("\n")
     invisible(x)
 }
-
